[PATCH] D31557: [mips][ias] Enable IAS by default for OpenBSD / FreeBSD mips64/mips64el.

Brad Smith via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Fri Mar 31 16:37:58 PDT 2017


brad created this revision.
Herald added a subscriber: emaste.

Enable IAS by default for OpenBSD / FreeBSD mips64/mips64el.

We're both in the same boat with binutils 2.17(.50) for the external assembler.
Both projects have been using IAS as its the only option and the only way forward. I'd like to push this combined diff forward.


Repository:
  rL LLVM

https://reviews.llvm.org/D31557

Files:
  lib/Target/Mips/MCTargetDesc/MipsMCAsmInfo.cpp


Index: lib/Target/Mips/MCTargetDesc/MipsMCAsmInfo.cpp
===================================================================
--- lib/Target/Mips/MCTargetDesc/MipsMCAsmInfo.cpp
+++ lib/Target/Mips/MCTargetDesc/MipsMCAsmInfo.cpp
@@ -60,7 +60,9 @@
       TheTriple.getArch() == Triple::mipsel)
     UseIntegratedAssembler = true;
 
-  // Enable IAS by default for Debian mips64/mips64el.
-  if (TheTriple.getEnvironment() == Triple::GNUABI64)
+  // Enable IAS by default for Debian / FreeBSD / OpenBSD mips64/mips64el.
+  if (TheTriple.getEnvironment() == Triple::GNUABI64 ||
+      TheTriple.getOS() == Triple::FreeBSD ||
+      TheTriple.getOS() == Triple::OpenBSD)
     UseIntegratedAssembler = true;
 }


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D31557.93723.patch
Type: text/x-patch
Size: 701 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20170331/56ce1091/attachment.bin>


More information about the llvm-commits mailing list